@@ -1,8 +1,10 @@
 #include "generator.ih"
 
+    // see also: insert.cc
+
 void Generator::debug(ostream &out) const
 {
-    if (!d_debug)
+    if (not debugTest())
         return;
 
     key(out);
