@@ -4,6 +4,8 @@
 //         begin, end: the begin/end state indices of the initial pattern
 //         beginEnd: vector of pairs holding begin and end indices of copied
 //                   patterns
+//
+//         lower and upper are the lower and upper limits of an Interval
 // 
 // First the initial number of required patterns is duplicated (the 1st one 
 //         already being available as it is `pattern' itself)
@@ -22,14 +24,14 @@
 Pattern Pattern::copy(States &states, 
                       Pattern &regex, size_t lower, size_t upper)
 {
-    PairVector beginEnd(1, States::Pair{regex.begin(), regex.end()});   
+    PairVector beginEnd(1, Pair{regex.begin(), regex.end()});   
                                                         // begin/end indices
                                                         // of the regex
 
     copyPattern(states, lower - 1, beginEnd);           // copy req'd patterns
 
     return
-        upper == numeric_limits<size_t>::max() ?    // no upper limit: 
+        upper == max<size_t>() ?    // no upper limit: 
             optRepeatLastPattern(states,            // optionally  repeat the 
                             regex, lower, beginEnd) // last pattern. 
         :                                       // Otherwise add fixed nr
@@ -38,4 +40,3 @@ Pattern Pattern::copy(States &states,
 }
 
 
-
