@@ -2,10 +2,10 @@
 
 void Ranges::add(string const &str)
 {
-    size_t *next = new size_t[d_size];
+    size_t *next = new size_t[d_alphabetSize];
     
-        // initialize next values with d_ranges
-    copy(d_ranges, d_ranges + d_size, next);
+        // initialize next values with d_alphabet
+    copy(d_alphabet, d_alphabet + d_alphabetSize, next);
 
         // increment next counts for chars in str
     for (auto &ch: str)
