@@ -4,16 +4,18 @@
 #include <iosfwd>
 #include <vector>
 #include <string>
-#include <unordered_map>
+
+#include <bobcat/linearmap>
 
 #include "../startconditions/startconditions.h"
 #include "../rule/rule.h"
+#include "../flextypes/flextypes.h"
 
 class States;
 class Block;
 class Pattern;
 
-class Rules
+class Rules: public FlexTypes
 {
     friend std::ostream &operator<<(std::ostream &out, Rules const &rules);
 
@@ -22,53 +24,140 @@ class Rules
     States &d_states;
 
     std::vector<Rule> d_rules;
-    std::unordered_map<size_t, size_t>  d_finalToRule;  // from FINAL state to
+    FBB::LinearMap<size_t, size_t>  d_finalToRule;  // from FINAL state to
                                                         // Rule index
+    FBB::LinearMap<size_t, size_t>  d_lopToRule;// key is lop rule,
+                                                    // value is rule to use
+                                                    // while in user SCs
+
     StartConditions d_startConditions;
 
+    Rule d_catchAll;
+    bool d_userSC = true;
+    bool d_hasFixedTailLOPrules = false;      
+    bool d_hasVariableTailLOPrules = false;      
+    size_t d_nUserRules = 0;
+
     public:
         typedef StartConditions::const_iterator const_iterator;
-        typedef StartConditions::NameVector NameVector;
         typedef std::vector<Rule>::const_iterator rule_const_iterator;
 
         Rules(States &states);
-        void add(bool bol, Pattern const &pattern, Block const &block);
+        void add(bool bol, Pattern const &pattern, Block const &block,
+                RuleType type);
 
         Rule const &operator[](size_t idx) const;
         Rule &operator[](size_t idx);
 
+        
         size_t ruleFromFinalState(size_t stateIdx) const;
+
         void setType(StartConditions::Type type);
-        void addStartCondition(std::string const &name);
-        void resetStartConditions();
+        void defineStartCondition(std::string const &name);
+
+        void resetStartConditions();        // clear the set of active start
+                                            // conditions. 
         void useAll();
-        void activateStartCondition(std::string const &name);
+        void addStartCondition(std::string const &name);
+
         std::vector<size_t> const &operator()   // vector of rule nrs
                                     (std::string const &startCondition) const;
-        void useInitialSC();
 
         const_iterator begin() const;
         const_iterator end() const;
+        const_iterator endUserSC() const;
 
         rule_const_iterator ruleBegin() const;
         rule_const_iterator ruleEnd() const;
 
-        size_t size() const;
+        size_t size() const;                    // # of rules
 
-        void warnNonViable() const;
         void setOrAction();         // set the previous rule's action to '|'
+
         void assignBlock(Block const &block);   // assign 'block' to the last
                                                 // rule
+
         void noActions();                       // clear previous actions's
                                                 // 'orAction' states
 
         StartConditions const &startConditions() const;
 
+        void handleLopRules();
+
+        void setEndUserSC();
+        void setNuserRules();
+
+        void processCatchAllRule();
+
+        void checkUserSC(size_t scIndex);
+
+        void setFixedTailLOPrules();
+        void setVariableTailLOPrules();
+
+        bool hasLOPrules() const;
+        bool hasFixedTailLOPrules() const;
+        bool hasVariableTailLOPrules() const;
+        size_t nUserRules() const;
+
     private:
         void setRule(size_t state, size_t index);
-        static bool nonViable(Rule const &rule);
+
+        void setLopBlocks();
+        size_t handleLopRule(size_t idx);
+        void handleFixedTailLopRule(Rule &rule);
+
+        void addIndex(size_t index);
+
+        void addCatchAll(size_t scIndex, size_t catchAllRuleIndex);
+
+//        static bool nonViable(Rule const &rule);
 };
 
+inline void Rules::setNuserRules()
+{
+    d_nUserRules = d_rules.size();
+}
+
+inline void Rules::setFixedTailLOPrules()
+{
+    d_hasFixedTailLOPrules = true;
+}
+
+inline void Rules::setVariableTailLOPrules()
+{
+    d_hasVariableTailLOPrules = true;
+}
+
+inline bool Rules::hasFixedTailLOPrules() const
+{
+    return d_hasFixedTailLOPrules;
+}
+
+inline bool Rules::hasVariableTailLOPrules() const
+{
+    return d_hasVariableTailLOPrules;
+}
+
+inline bool Rules::hasLOPrules() const
+{
+    return hasFixedTailLOPrules() || hasVariableTailLOPrules();
+}
+
+inline void Rules::addIndex(size_t index)
+{
+    d_startConditions.add(index);
+}
+
+inline void Rules::checkUserSC(size_t idx)
+{
+    d_userSC = d_userSC && idx < d_startConditions.nUserSCs();
+}
+
+inline void Rules::setEndUserSC()
+{
+    d_startConditions.setEndUserSC();
+}
+
 inline StartConditions const &Rules::startConditions() const
 {
     return d_startConditions;
@@ -84,6 +173,11 @@ inline size_t Rules::size() const
     return d_rules.size();
 }
         
+inline size_t Rules::nUserRules() const
+{
+    return d_nUserRules;
+}
+
 inline Rules::const_iterator Rules::begin() const
 {
     return d_startConditions.begin();
@@ -94,6 +188,11 @@ inline Rules::const_iterator Rules::end() const
     return d_startConditions.end();
 }
         
+inline Rules::const_iterator Rules::endUserSC() const
+{
+    return d_startConditions.endUserSC();
+}
+        
 inline Rules::rule_const_iterator Rules::ruleBegin() const
 {
     return d_rules.begin();
@@ -104,11 +203,6 @@ inline Rules::rule_const_iterator Rules::ruleEnd() const
     return d_rules.end();
 }
         
-inline size_t Rules::ruleFromFinalState(size_t stateIdx) const
-{
-    return d_finalToRule.find(stateIdx)->second;
-}
-
 inline Rule const &Rules::operator[](size_t idx) const
 {
     return d_rules[idx];
@@ -124,9 +218,9 @@ inline void Rules::setType(StartConditions::Type type)
     d_startConditions.setType(type);
 }
 
-inline void Rules::addStartCondition(std::string const &name)
+inline void Rules::defineStartCondition(std::string const &name)
 {
-    d_startConditions.add(name);
+    d_startConditions.define(name);
 }
 
 inline void Rules::resetStartConditions()
@@ -139,14 +233,14 @@ inline void Rules::useAll()
     d_startConditions.useAll();
 }
 
-inline void Rules::activateStartCondition(std::string const &name)
+inline void Rules::addStartCondition(std::string const &name)
 {
-    d_startConditions.activate(name);
+    d_startConditions.addSC(name);
 }
 
-inline void Rules::useInitialSC()
+inline void Rules::assignBlock(Block const &block)
 {
-    d_startConditions.useInitialSC();
+    d_rules.back().assignBlock(block);    
 }
 
 inline std::vector<size_t> const &Rules::operator() 
@@ -155,9 +249,4 @@ inline std::vector<size_t> const &Rules::operator()
     return d_startConditions(startCondition);
 }
 
-inline void Rules::assignBlock(Block const &block)
-{
-    d_rules.back().assignBlock(block);    
-}
-
 #endif
