@@ -5,7 +5,8 @@ Scanner::Scanner(string const &fname)
     ScannerBase(fname, "-"),
     d_inBlock(false),
     d_inCharClass(false),
-    d_acceptMulti(true)
+    d_acceptMulti(true),
+    d_caseSensitive(true)
 {
     setLineTags(fname);
     push(StartCondition__::pre);
