@@ -2,7 +2,7 @@
 
 void States::collect(size_t idx)
 {
-    d_state[idx].setType(State::UNDETERMINED__);
+    d_state[idx].setType(UNDETERMINED__);
     return d_free.push_back(idx);
 }
 
